from .aws_secrets_manager_get_secret_value_request import AWSSecretsManagerGetSecretValueRequest as AWSSecretsManagerGetSecretValueRequest
from .aws_secrets_manager_get_secret_value_response import AWSSecretManagerGetSecretValueResponse as AWSSecretManagerGetSecretValueResponse