from typing import Literal


AthenaConnectionType = Literal[
    'DYNAMODB',
    'MYSQL',
    'POSTGRESQL',
    'REDSHIFT',
    'ORACLE',
    'SYNAPSE',
    'SQLSERVER',
    'DB2',
    'OPENSEARCH',
    'BIGQUERY',
    'GOOGLECLOUDSTORAGE',
    'HBASE',
    'DOCUMENTDB',
    'CMDB',
    'TPCDS',
    'TIMESTREAM',
    'SAPHANA',
    'SNOWFLAKE',
    'DATALAKEGEN2',
    'DB2AS400',
]

