from typing import Literal


SupportedClients = Literal[
    "athena",
    "cloudwatch",
    "code_artifact",
    "cost_explorer",
    "ec2",
    "elasticache",
    "msk",
    "organizations",
    "sts",
]
