from .athena_acl_configuration import AthenaAclConfiguration as AthenaAclConfiguration
from .athena_calculation_configuration import AthenaCalculationConfiguration as AthenaCalculationConfiguration
from .athena_calculation_result import AthenaCalculationResult as AthenaCalculationResult
from .athena_calculation_state import AthenaCalculationState as AthenaCalculationState
from .athena_calculation_statistics import AthenaCalculationStatistics as AthenaCalculationStatistics
from .athena_calculation_status import AthenaCalculationStatus as AthenaCalculationStatus
from .athena_column_info import AthenaColumnInfo as AthenaColumnInfo
from .athena_column_nullable import AthenaColumnNullable as AthenaColumnNullable
from .athena_connection_type import AthenaConnectionType as AthenaConnectionType
from .athena_create_data_catalog_request import AthenaCreateDataCatalogRequest as AthenaCreateDataCatalogRequest
from .athena_create_data_catalog_response import AthenaCreateDataCatalogResponse as AthenaCreateDataCatalogResponse
from .athena_create_named_query_request import AthenaCreateNamedQueryRequest  as AthenaCreateNamedQueryRequest
from .athena_create_named_query_response import AthenaCreateNamedQueryResponse as AthenaCreateNamedQueryResponse
from .athena_create_prepared_statement_request import AthenaCreatePreparedStatementRequest as AthenaCreatePreparedStatementRequest
from .athena_create_prepared_statement_response import AthenaCreatePreparedStatementResponse as AthenaCreatePreparedStatementResponse
from .athena_data_catalog import AthenaDataCatalog as AthenaDataCatalog
from .athena_data_catalog_status import AthenaDataCatalogStatus as AthenaDataCatalogStatus
from .athena_data_catalog_summary import AthenaDataCatalogSummary as AthenaDataCatalogSummary
from .athena_data_catalog_type import AthenaDataCatalogType as AthenaDataCatalogType
from .athena_database import AthenaDatabase as AthenaDatabase
from .athena_delete_data_catalog_request import AthenaDeleteDataCatalogRequest as AthenaDeleteDataCatalogRequest
from .athena_delete_data_catalog_response import AthenaDeleteDataCatalogResponse as AthenaDeleteDataCatalogResponse
from .athena_delete_named_query_request import AthenaDeleteNamedQueryRequest as AthenaDeleteNamedQueryRequest
from .athena_delete_named_query_response import AthenaDeleteNamedQueryResponse as AthenaDeleteNamedQueryResponse
from .athena_delete_prepared_statement_request import AthenaDeletePreparedStatementRequest as AthenaDeletePreparedStatementRequest
from .athena_delete_prepared_statement_response import AthenaDeletePreparedStatementResponse as AthenaDeletePreparedStatementResponse
from .athena_encryption_configuration import AthenaEncryptionConfiguration as AthenaEncryptionConfiguration
from .athena_encryption_option import AthenaEncryptionOption as AthenaEncryptionOption
from .athena_engine_configuration import AthenaEngineConfiguration as AthenaEngineConfiguration
from .athena_engine_version import AthenaEngineVersion as AthenaEngineVersion
from .athena_get_calculation_execution_code_request import AthenaGetCalculationExectutionCodeRequest as AthenaGetCalculationExectutionCodeRequest
from .athena_get_calculation_execution_code_response import AthenaGetCalculationExecutionCodeResponse as AthenaGetCalculationExecutionCodeResponse
from .athena_get_calculation_execution_request import AthenaGetCalculationExecutionRequest as AthenaGetCalculationExecutionRequest
from .athena_get_calculation_execution_response import AthenaGetCalculationExecutionResponse as AthenaGetCalculationExecutionResponse
from .athena_get_calculation_execution_status_request import AthenaGetCalculationExecutionStatusRequest as AthenaGetCalculationExecutionStatusRequest
from .athena_get_calculation_execution_status_response import AthenaGetCalculationExecutionStatusResponse as AthenaGetCalculationExecutionStatusResponse
from .athena_get_data_catalog_request import AthenaGetDataCatalogRequest as AthenaGetDataCatalogRequest
from .athena_get_data_catalog_response import AthenaGetDataCatalogResponse as AthenaGetDataCatalogResponse
from .athena_get_database_request import AthenaGetDatabaseRequest as AthenaGetDatabaseRequest
from .athena_get_database_response import AthenaGetDatabaseResponse as AthenaGetDatabaseResponse
from .athena_get_named_query_request import AthenaGetNamedQueryRequest as AthenaGetNamedQueryRequest
from .athena_get_named_query_response import AthenaGetNamedQueryResponse as AthenaGetNamedQueryResponse
from .athena_get_prepared_statement_request import AthenaGetPreparedStatementRequest as AthenaGetPreparedStatementRequest
from .athena_get_prepared_statement_response import AthenaGetPreparedStatementResponse as AthenaGetPreparedStatementResponse
from .athena_get_query_execution_request import AthenaGetQueryExecutionRequest as AthenaGetQueryExecutionRequest
from .athena_get_query_execution_response import AthenaGetQueryExecutionResponse as AthenaGetQueryExecutionResponse
from .athena_get_query_results_request import AthenaGetQueryResultsRequest as AthenaGetQueryResultsRequest
from .athena_get_query_results_response import AthenaGetQueryResultsResponse as AthenaGetQueryResultsResponse
from .athena_get_session_request import AthenaGetSessionRequest as AthenaGetSessionRequest
from .athena_get_session_response import AthenaGetSessionResponse as AthenaGetSessionResponse
from .athena_get_session_status_request import AthenaGetSessionStatusRequest as AthenaGetSessionStatusRequest
from .athena_get_session_status_response import AthenaGetSessionStatusResponse as AthenaGetSessionStatusResponse
from .athena_list_data_catalogs_request import AthenaListDataCatalogsRequest as AthenaListDataCatalogsRequest
from .athena_list_data_catalogs_response import AthenaListDataCatalogsResponse as AthenaListDataCatalogsResponse
from .athena_list_databases_request import AthenaListDatabasesRequest as AthenaListDatabasesRequest
from .athena_list_databases_response import AthenaListDatabasesResponse as AthenaListDatabasesResponse
from .athena_list_named_queries_request import AthenaListNamedQueriesRequest as AthenaListNamedQueriesRequest
from .athena_list_named_queries_response import AthenaListNamedQueriesResponse as AthenaListNamedQueriesResponse
from .athena_list_prepared_statements_request import AthenaListPreparedStatementsRequest as AthenaListPreparedStatementsRequest
from .athena_list_prepared_statements_response import AthenaListPreparedStatementsResponse as AthenaListPreparedStatementsResponse
from .athena_list_query_executions_request import AthenaListQueryExecutionsRequest as AthenaListQueryExecutionsRequest
from .athena_list_query_executions_response import AthenaListQueryExecutionsResponse as AthenaListQueryExecutionsResponse
from .athena_list_sessions_request import AthenaListSessionsRequest as AthenaListSessionsRequest
from .athena_list_sessions_response import AthenaListSessionsResponse as AthenaListSessionsResponse
from .athena_managed_query_results_configuration import AthenaManagedQueryResultsConfiguration as AthenaManagedQueryResultsConfiguration
from .athena_named_query import AthenaNamedQuery as AthenaNamedQuery
from .athena_prepared_statement import AthenaPreparedStatement as AthenaPreparedStatement
from .athena_query_error import AthenaQueryError as AthenaQueryError
from .athena_query_execution_context import AthenaQueryExecutionContext as AthenaQueryExecutionContext
from .athena_query_execution import AthenaQueryExecution as AthenaQueryExecution
from .athena_query_result_type import AthenaQueryResultType as AthenaQueryResultType
from .athena_query_results_s3_access_grants_configruation import AthenaQueryResultsS3AccessGrantsConfiguration as AthenaQueryResultsS3AccessGrantsConfiguration
from .athena_query_state import AthenaQueryState as AthenaQueryState
from .athena_query_statistics import AthenaQueryStatistics as AthenaQueryStatistics
from .athena_query_status import AthenaQueryStatus as AthenaQueryStatus
from .athena_result_configuration import AthenaResultConfigruation as AthenaResultConfigruation
from .athena_result_reuse_by_age_configuration import AthenaResultReuseByAgeConfiguration as AthenaResultReuseByAgeConfiguration
from .athena_result_reuse_information import AthenaResultReuseInformation as AthenaResultReuseInformation
from .athena_result_set_metadata import AthenaResultSetMetadata as AthenaResultSetMetadata
from .athena_result_set import AthenaResultSet as AthenaResultSet
from .athena_row import AthenaRow as AthenaRow
from .athena_session_configuration import AthenaSessionConfiguration as AthenaSessionConfiguration
from .athena_session_state import AthenaSessionState as AthenaSessionState
from .athena_session_statistics import AthenaSessionStatistics as AthenaSessionStatistics
from .athena_session_status import AthenaSessionStatus as AthenaSessionStatus
from .athena_session import AthenaSession as AthenaSession
from .athena_start_calculation_execution_request import AthenaStartCalculationExecutionRequest as AthenaStartCalculationExecutionRequest
from .athena_start_calculation_execution_response import AthenaStartCalculationExecutionResponse as AthenaStartCalculationExecutionResponse
from .athena_start_query_execution_request import AthenaStartQueryExecutionRequest as AthenaStartQueryExecutionRequest
from .athena_start_query_execution_response import AthenaStartQueryExecutionResponse as AthenaStartQueryExecutionResponse
from .athena_start_session_request import AthenaStartSessionRequest as AthenaStartSessionRequest
from .athena_start_session_response import AthenaStartSessionResponse as AthenaStartSessionResponse
from .athena_statement_type import AthenaStatementType as AthenaStatementType
from .athena_stop_calculation_execution_request import AthenaStopCalculationExecutionRequest as AthenaStopCalculationExecutionRequest
from .athena_stop_calculation_execution_response import AthenaStopCalculationExecutionResponse as AthenaStopCalculationExecutionResponse
from .athena_stop_query_execution_request import AthenaStopQueryExecutionRequest as AthenaStopQueryExecutionRequest
from .athena_stop_query_execution_response import AthenaStopQueryExecutionResponse as AthenaStopQueryExecutionResponse
from .athena_tag import AthenaTag as AthenaTag
from .athena_terminate_session_request import AthenaTerminateSessionRequest as AthenaTerminateSessionRequest
from .athena_terminate_session_response import AthenaTerminateSessionResponse as AthenaTerminateSessionResponse
from .athena_update_data_catalog_request import AthenaUpdateDataCatalogRequest as AthenaUpdateDataCatalogRequest
from .athena_update_data_catalog_response import AthenaUpdateDataCatalogResponse as AthenaUpdateDataCatalogResponse
from .athena_update_named_query_request import AthenaUpdateNamedQueryRequest as AthenaUpdateNamedQueryRequest
from .athena_update_named_query_response import AthenaUpdateNamedQueryResponse as AthenaUpdateNamedQueryResponse
from .athena_var_char_value import AthenaVarCharValue as AthenaVarCharValue